@@ -80,7 +80,7 @@ class JaxlAppStreamingAIAgent(BaseJaxlApp):
             del self._states[req.state.call_id]
         return None
 
-    async def handle_speech_detection(self, speaking: bool) -> None:
+    async def handle_speech_detection(self, call_id: int, speaking: bool) -> None:
         print("🎙️" if speaking else "🤐")
 
     async def handle_transcription(
