@@ -9,20 +9,34 @@ with or without modification, is strictly prohibited.
 
 import argparse
 import uuid
-from typing import Any, Dict, List, Optional, Tuple, cast
+from typing import Any, Dict, List, Optional, Tuple, Union, cast
 
 from jaxl.api._client import JaxlApiModule, jaxl_api_client
 from jaxl.api.client.api.v1 import (
     v1_calls_add_create,
+    v1_calls_hangup_retrieve,
     v1_calls_list,
+    v1_calls_retrieve,
+    v1_calls_tags_create,
     v1_calls_token_create,
+    v1_calls_transfer_create,
+    v1_calls_tts_create,
     v1_calls_usage_retrieve,
 )
+from jaxl.api.client.models.call import Call
 from jaxl.api.client.models.call_add_request_request import (
     CallAddRequestRequest,
 )
+from jaxl.api.client.models.call_tag_request import CallTagRequest
+from jaxl.api.client.models.call_tag_response import CallTagResponse
 from jaxl.api.client.models.call_token_request import CallTokenRequest
 from jaxl.api.client.models.call_token_response import CallTokenResponse
+from jaxl.api.client.models.call_transfer_request_request import (
+    CallTransferRequestRequest,
+)
+from jaxl.api.client.models.call_tts_request_request import (
+    CallTtsRequestRequest,
+)
 from jaxl.api.client.models.call_type_enum import CallTypeEnum
 from jaxl.api.client.models.call_usage_response import CallUsageResponse
 from jaxl.api.client.models.paginated_call_list import PaginatedCallList
@@ -31,6 +45,8 @@ from jaxl.api.resources._constants import DEFAULT_CURRENCY, DEFAULT_LIST_LIMIT
 from jaxl.api.resources.ivrs import (
     IVR_CTA_KEYS,
     IVR_INPUTS,
+    add_next_or_cta_flags,
+    create_next_or_cta,
     ivrs_create,
     ivrs_options_create,
 )
@@ -50,7 +66,7 @@ def calls_usage(args: Dict[str, Any]) -> Response[CallUsageResponse]:
 
 def ivrs_create_adhoc(
     message: str,
-    inputs: Optional[Dict[str, Tuple[str, str, str]]] = None,
+    inputs: Optional[Dict[str, Tuple[str, str, Union[List[str], str]]]] = None,
     hangup: bool = False,
 ) -> int:
     if (hangup is True and inputs is not None) or (hangup is False and inputs is None):
@@ -122,7 +138,20 @@ def calls_create(args: Dict[str, Any]) -> Response[CallTokenResponse]:
                 cta, value = parts[1].split("=", 1)
                 if cta not in IVR_CTA_KEYS or input_ not in IVR_INPUTS:
                     raise ValueError(f"Invalid CTA key {cta} or input {input_}")
-                inputs[input_] = (name, cta, value)
+                inputs[input_] = (
+                    name,
+                    cta,
+                    (
+                        value.split(",")
+                        if cta
+                        in (
+                            "devices",
+                            "appusers",
+                            "teams",
+                        )
+                        else value
+                    ),
+                )
             ivr_id = ivrs_create_adhoc(message, inputs)
             if ivr_id is None:
                 raise ValueError("Unable to create ad-hoc IVR")
@@ -148,6 +177,20 @@ def calls_create(args: Dict[str, Any]) -> Response[CallTokenResponse]:
     )
 
 
+def calls_get(args: Optional[Dict[str, Any]] = None) -> Response[Call]:
+    """Get a call"""
+    args = args or {}
+    return v1_calls_retrieve.sync_detailed(
+        id=args["call_id"],
+        client=jaxl_api_client(
+            JaxlApiModule.CALL,
+            credentials=args.get("credentials", None),
+            auth_token=args.get("auth_token", None),
+        ),
+        currency=args.get("currency", DEFAULT_CURRENCY),
+    )
+
+
 def calls_list(args: Optional[Dict[str, Any]] = None) -> Response[PaginatedCallList]:
     """List calls"""
     args = args or {}
@@ -178,8 +221,54 @@ def calls_add(args: Dict[str, Any]) -> Response[Any]:
     )
 
 
-# def calls_hangup(args: Optional[Dict[str, Any]] = None) -> Response[PaginatedCallList]:
-#     pass
+def calls_tts(args: Dict[str, Any]) -> Response[Any]:
+    return v1_calls_tts_create.sync_detailed(
+        id=args["call_id"],
+        client=jaxl_api_client(
+            JaxlApiModule.CALL,
+            credentials=args.get("credentials", None),
+            auth_token=args.get("auth_token", None),
+        ),
+        json_body=CallTtsRequestRequest(
+            prompts=[pro for pro in args["prompt"].split(".") if len(pro.strip()) > 0],
+            mark=args.get("mark", None),
+        ),
+    )
+
+
+def calls_tag_add(args: Dict[str, Any]) -> Response[CallTagResponse]:
+    return v1_calls_tags_create.sync_detailed(
+        call_id=args["call_id"],
+        client=jaxl_api_client(
+            JaxlApiModule.CALL,
+            credentials=args.get("credentials", None),
+            auth_token=args.get("auth_token", None),
+        ),
+        json_body=CallTagRequest(name=args["tag"]),
+    )
+
+
+def calls_hangup(args: Dict[str, Any]) -> Response[Any]:
+    return v1_calls_hangup_retrieve.sync_detailed(
+        id=args["call_id"],
+        client=jaxl_api_client(
+            JaxlApiModule.CALL,
+            credentials=args.get("credentials", None),
+            auth_token=args.get("auth_token", None),
+        ),
+    )
+
+
+def calls_transfer(args: Dict[str, Any]) -> Response[Any]:
+    return v1_calls_transfer_create.sync_detailed(
+        id=args["call_id"],
+        client=jaxl_api_client(
+            JaxlApiModule.CALL,
+            credentials=args.get("credentials", None),
+            auth_token=args.get("auth_token", None),
+        ),
+        json_body=CallTransferRequestRequest(next_or_cta=create_next_or_cta(args)),
+    )
 
 
 def _subparser(parser: argparse.ArgumentParser) -> None:
@@ -289,11 +378,54 @@ def _subparser(parser: argparse.ArgumentParser) -> None:
         ],
     )
 
+    calls_tts_parser = subparsers.add_parser(
+        "tts", help="Send text prompts in an active call"
+    )
+    calls_tts_parser.add_argument(
+        "--call-id",
+        type=int,
+        required=True,
+        help="Call ID",
+    )
+    calls_tts_parser.add_argument(
+        "--prompt",
+        type=str,
+        required=True,
+    )
+    calls_tts_parser.set_defaults(func=calls_tts, _arg_keys=["call_id", "prompt"])
+
+    calls_get_parser = subparsers.add_parser("get", help="Get a call detail")
+    calls_get_parser.add_argument(
+        "--call-id",
+        type=int,
+        required=True,
+        help="Call ID",
+    )
+    calls_get_parser.set_defaults(func=calls_get, _arg_keys=["call_id"])
+
     # hangup
-    # calls_hangup_parser = subparsers.add_parser("hangup", help="Hangup calls")
-    # calls_hangup_parser.set_defaults(func=calls_hangup, _arg_keys=[])
+    calls_hangup_parser = subparsers.add_parser("hangup", help="Hangup call")
+    calls_hangup_parser.add_argument(
+        "--call-id",
+        type=int,
+        required=True,
+        help="Call ID",
+    )
+    calls_hangup_parser.set_defaults(func=calls_hangup, _arg_keys=["call_id"])
 
     # transfer
+    calls_transfer_parser = subparsers.add_parser("transfer", help="Transfer call")
+    calls_transfer_parser.add_argument(
+        "--call-id",
+        type=int,
+        required=True,
+        help="Call ID",
+    )
+    _group = add_next_or_cta_flags(calls_transfer_parser)
+    calls_transfer_parser.set_defaults(
+        func=calls_transfer,
+        _arg_keys=["call_id"] + IVR_CTA_KEYS,
+    )
 
     # add
     # remove
@@ -302,7 +434,6 @@ def _subparser(parser: argparse.ArgumentParser) -> None:
     # hold/unhold
 
     # play
-    # say
 
     # ivr (send active call into an ivr)
 
@@ -338,3 +469,15 @@ class JaxlCallsSDK:
 
     def add(self, **kwargs: Any) -> Response[Any]:
         return calls_add(kwargs)
+
+    def tts(self, **kwargs: Any) -> Response[Any]:
+        return calls_tts(kwargs)
+
+    def get(self, **kwargs: Any) -> Response[Call]:
+        return calls_get(kwargs)
+
+    def add_tag(self, **kwargs: Any) -> Response[CallTagResponse]:
+        return calls_tag_add(kwargs)
+
+    def hangup(self, **kwargs: Any) -> Response[Any]:
+        return calls_hangup(kwargs)
